@@ -13,6 +13,7 @@ from argparse import (
     ArgumentDefaultsHelpFormatter,
     RawDescriptionHelpFormatter,
 )
+from typing import Generator
 from pathlib import Path
 import datetime
 import sys
@@ -76,3 +77,31 @@ def get_parser():
     )
 
     return parser
+
+
+def main(
+    parser = get_parser()
+) -> aws_spitzel.ProgramContext:
+    """main program execution handled by a command-line interface
+
+    :param parser: argparse parser to use
+    """
+
+    argv = vars(parser.parse_args())
+
+    if argv.get('last_minute', None):
+
+        from_ = datetime.datetime.now() - datetime.timedelta(minutes=argv['last_minute'])
+
+    else:
+
+        from_ = argv['from']
+
+    return aws_spitzel.ProgramContext(
+        actions=argv['action'],
+        filters=argv['match'],
+        date_range=aws_spitzel.DateRange(
+            start=from_,
+            end=argv['to']
+        )
+    ), argv
\ No newline at end of file
